@@ -1,31 +1,24 @@
-/***************************************************************************
- *   Copyright (C) 2004, 2005 by Jakub Stachowski                                *
- *   qbast@go2.pl                                                          *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.             *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2004, 2005 Jakub Stachowski <qbast@go2.pl>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #ifndef _dnssd_H_
 #define _dnssd_H_
 
-// KDE
+// KF
+#include <KIO/SlaveBase>
+#include <kdnssd_version.h>
+#if KDNSSD_VERSION >= QT_VERSION_CHECK(5, 84, 0)
+#include <KDNSSD/ServiceBrowser>
+#include <KDNSSD/ServiceTypeBrowser>
+#include <KDNSSD/RemoteService>
+#else
 #include <DNSSD/ServiceBrowser>
 #include <DNSSD/ServiceTypeBrowser>
 #include <DNSSD/RemoteService>
-#include <KIO/SlaveBase>
+#endif
 // Qt
 #include <QObject>
 
@@ -74,6 +67,8 @@ private:
     // resolve given service and redirect() to it
     void resolveAndRedirect( const ZeroConfUrl& zeroConfUrl );
 
+    void listCurrentDirEntry();
+
     bool dnssdOK();
 
     void enterLoop();
